This crate contains kube-rs compatible bindings for Kubernetes custom resources for the registry.apicur.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
registry.apicur.io/v1
ApicurioRegistry